Author: Landscape Fire and Resource Management Planning Tools (LANDFIRE) Earth Resources Observation and Science Center (EROS) U.S. Geological Survey (USGS) Timothy Hatten, USGS PM
Description: LANDFIRE's (LF) 2022 Canopy Bulk Density (CBD) describes the mass of available canopy fuel per unit canopy volume that would burn in a crown fire. A spatially explicit map of CBD supplies information used in fire behavior models to determine the spread characteristics of active crown fires across the landscape. CBD for disturbed and non-disturbed areas is determined via a general linear model (GLM) relating Canopy Height (CH) and Canopy Cover (CC) to CBD (Reeves et al 2009). In LF 2022, fuel products are created with LF 2016 Remap vegetation in areas that were un-disturbed in the last ten years. To designate disturbed areas where CBD is modified, the aggregated Annual Disturbance products from 2013 to 2022 in the Fuel Disturbance (FDist) product are used. All existing disturbances between 2013-2022 are represented in the LF 2022 update, and the products are intended to be used in 2023 (the year of release). The "capable" year terminology used in LF 2020 and LF 2016 Remap is no longer s [cell cut: 1440 characters, first 1000 kept]
Keywords: imageryBaseMapsEarthCover biota
Date: 20230501

# LANDFIRE 2022 Forest Canopy Bulk Density (CBD) CONUS

Metadata also available as

# Metadata:

- Identification_Information
- Data_Quality_Information
- Spatial_Data_Organization_Information
- Spatial_Reference_Information
- Entity_and_Attribute_Information
- Distribution_Information
- Metadata_Reference_Information

Identification_Information:
  Citation:
    Citation_Information:
      Originator:
        Landscape Fire and Resource Management Planning Tools (LANDFIRE)
      Originator: Earth Resources Observation and Science Center (EROS)
      Originator: U.S. Geological Survey (USGS)
      Originator: Timothy Hatten, USGS PM
      Publication_Date: 20230501
      Title: LANDFIRE 2022 Forest Canopy Bulk Density (CBD) CONUS
      Edition: LF 2022
      Geospatial_Data_Presentation_Form: raster digital data
      Publication_Information:
        Publication_Place: Sioux Falls, SD
        Publisher:
          Earth Resources Observation and Science Center (EROS), U.S. Geological Survey
      Online_Linkage: https://www.landfire.gov
      Online_Linkage: https://doi.org/10.5066/P974JF8W
  Description:
    Abstract:
      LANDFIRE's (LF) 2022 Canopy Bulk Density (CBD) describes the mass of available canopy fuel per unit canopy volume that would burn in a crown fire. A spatially explicit map of CBD supplies information used in fire behavior models to determine the spread characteristics of active crown fires across the landscape. CBD for disturbed and non-disturbed areas is determined via a general linear model (GLM) relating Canopy Height (CH) and Canopy Cover (CC) to CBD (Reeves et al 2009). In LF 2022, fuel products are created with LF 2016 Remap vegetation in areas that were un-disturbed in the last ten years.
      To designate disturbed areas where CBD is modified, the aggregated Annual Disturbance products from 2013 to 2022 in the Fuel Disturbance (FDist) product are used. All existing disturbances between 2013-2022 are represented in the LF 2022 update, and the products are intended to be used in 2023 (the year of release). The "capable" year terminology used in LF 2020 and LF 2016 Remap is no longer specified, due to reduction in latency from when a disturbance occurs to the release date of fuel products accounting for that disturbance. However, users should still consider adjusting fuel layers for disturbances that occurred after the end of the 2022 fiscal year (after October 1st, 2022) when using the LF 2022 fuel products. Because those changes would not be accounted for. Learn more about LF 2022 at https://landfire.gov/lf_230.php
    Purpose:
      The LANDFIRE 2022 Update (LF 2022) is designed to produce vegetation, disturbance, and fuels products that inform wildland fire and ecological decision systems. LF 2022 is another update to the LF 2016 Remap base map and LF 2020, it includes adjustments to vegetation and fuels in disturbed areas for disturbances recorded in 2021 and 2022. Disturbances in 2022 represent the first full fiscal year of disturbance. Transition rulesets for vegetation account for disturbances from 2017 to 2022 while fuel updates utilize 2012 to 2022 disturbances. In LF 2022 Existing Vegetation Type (EVT) Ecological Systems classifications are the same as LF 2020, except in areas where agriculture or urban areas have changed. LF 2022 contains the first application of the "zero to one" Time Since Disturbance (TSD) rules for EVC and EVH transition rules. Both LF Existing Vegetation Cover (EVC) and Height (EVH), as well as all fuels products, are 2023 capable in disturbed areas.
      LF 2022 products are designed to facilitate national and regional level strategic fire and resource management planning and reporting of management activities. The principal purposes of the products include providing, 1) national level, landscape scale geospatial products to support fire and fuels management planning, and 2) consistent fuels products to support fire planning, analysis, and budgeting to evaluate fire management alternatives.
      Products are created at a 30 meter raster; however, the applicability of products varies by location and specific use. LF products were designed to support 1) national (all states) strategic planning, 2) regional (single large states or groups of smaller states), and 3) strategic/tactical planning for large sub regional landscapes and Fire Management Units (FMUs) (such as significant portions of states or multiple federal administrative entities). The applicability of LF products to support fire and land management planning on smaller areas will vary by product, location, and specific use. Managers and planners must evaluate LF products according to the scale and requirements specific to their needs.
    Supplemental_Information:
      Units are (kg/m^3 )*100 . To retrieve the real data value, user must divide the raster values in this data set by 100. The conversion from (kg/m^3 ) to (lb/ft^3 ) is 0.061728 (multiply (kg/m^3 ) by 0.061728). CBD Data Range: 0 - 0.45 (kg/m^3 ) (0 - 45 on the map) 0.45 = thematic class of all values greater than or equal to 0.45 meters. Beginning in the LF 2020 update and continued into the LF 2022 update, all CONUS products are created with a 90km buffer into both Canada and Mexico. The data in this buffer was last updated in LF 2020. LF 2022 AK products also feature a 90km buffer into Canada, but this buffer was last updated with new data in LF 2016 Remap. The following LF 2022 products have 2023 capability functionality: EVH, EVC, CBD, CBH, CC, CH, F13, F40, FVC, FVH, FVT, CFFDRS and FDist.
  Time_Period_of_Content:
    Time_Period_Information:
      Single_Date/Time:
        Calendar_Date: 2022
    Currentness_Reference: ground condition
  Status:
    Progress: Complete
    Maintenance_and_Update_Frequency: Annually
  Spatial_Domain:
    Bounding_Coordinates:
      West_Bounding_Coordinate: -72.6555
      East_Bounding_Coordinate: -72.4909
      North_Bounding_Coordinate: 44.4821
      South_Bounding_Coordinate: 44.3413
  Keywords:
    Theme:
      Theme_Keyword_Thesaurus: ISO 19115 Topic Category
      Theme_Keyword: imageryBaseMapsEarthCover
      Theme_Keyword: biota
    Theme:
      Theme_Keyword_Thesaurus: USGS Thesaurus
      Theme_Keyword: fires
      Theme_Keyword: hazard preparedness
      Theme_Keyword: remote sensing
      Theme_Keyword: image collections
      Theme_Keyword: geospatial datasets
      Theme_Keyword: geographic information systems
    Theme:
      Theme_Keyword_Thesaurus: None
      Theme_Keyword: raster digital data
      Theme_Keyword: Canopy Bulk Density
      Theme_Keyword: CBD
      Theme_Keyword: U.S. Geological Survey (USGS)
      Theme_Keyword: U.S. Forest Service (USFS)
      Theme_Keyword: LANDFIRE 2022
      Theme_Keyword: LF 2022
    Place:
      Place_Keyword_Thesaurus: Common geographic areas
      Place_Keyword: US
      Place_Keyword: CONUS
      Place_Keyword: United States
      Place_Keyword: Continental U.S.
      Place_Keyword: Conterminous United States
  Access_Constraints: None
  Use_Constraints: None
  Point_of_Contact:
    Contact_Information:
      Contact_Organization_Primary:
        Contact_Organization:
          LANDFIRE, Earth Resources Observation and Science Center (EROS), U.S. Geological Survey
      Contact_Position: Customer Service Representative
      Contact_Address:
        Address_Type: physical
        Address: 47914 252nd Street
        City: Sioux Falls
        State_or_Province: SD
        Postal_Code: 57198
        Country: U.S.
      Contact_Voice_Telephone: 605-594-6151
      Contact_Electronic_Mail_Address: helpdesk@landfire.gov
  Data_Set_Credit:
    These products were created by the LF team at USGS EROS, Sioux Falls, SD. Refer to the contact information throughout this metadata to contact the LF team.
  Security_Information:
    Security_Classification_System: None in place
    Security_Classification: Unclassified
    Security_Handling_Description:
      If there is ever doubt, contact the LF Help Desk at helpdesk@landfire.gov
  Native_Data_Set_Environment: Microsoft Windows 10; ESRI ArcCatalog 10.7.1

Data_Quality_Information:
  Attribute_Accuracy:
    Attribute_Accuracy_Report:
      Products were tested to ensure that each attribute is represented consistently across all data sets. Attributes were not validated against in person observations.
  Logical_Consistency_Report:
    The products were pixel "truth" tested for consistency of land or water characteristics across all products.
  Completeness_Report:
    Products were formally tested to ensure that valid data was produced for all pixels. Each product was then validated and tested for duplicates, omissions, and errors.
  Lineage:
    Process_Step:
      Process_Description:
        Beginning with the new base map of LF 2016 Remap (LF Remap), products were created using recent advances in image compositing, tiling algorithms, and faster computing hardware to ensure that LF products remained relevant. LF Remap leveraged the Landsat archive, lidar data, and user contributed field plot data compiled into the LF Reference Database (LFRDB), to create new vegetation products.
        Reference resources included, but were not limited to, Forest Inventory and Analysis (FIA) program plot data (USFS https://fia.fs.fed.us/), Landsat Dynamic Surface Water Extent [(DSWE) USGS https://www.usgs.gov/landsat-missions], the National Land Cover Database [(NLCD) USGS https://www.mrlc.gov/data], and National Agricultural Statistics Service [(NASS) USDA - https://www.nass.usda.gov/].
        For LF 2022 reference resources included, but were not limited to, Monitoring Trends in Burn Severity [(MTBS) USGS https://mtbs.gov/], Burned Area Reflectance Classification [(BARC) USFS and USGS] and Rapid Assessment of Vegetation Condition after Wildfire [(RAVG) https://burnseverity.cr.usgs.gov/ravg/], National Agricultural Statistics Service [(NASS) USDA - https://www.nass.usda.gov/] for 2022, PAD 3.0 for federal and protected lands identification [https://doi.org/10.5066/P9Q9LQ4B], and a rasterized version of the Microsoft building footprint for 2022 to update developed areas [https://github.com/Microsoft/USBuildingFootprints]. Disturbances in LF 2022 were also identified with LF's remote sensing of landscape change (RSLC), which identifies spectral change in vegetation using automated algorithms and image analyst review of the entire country with Landsat imagery. Burned Area (BA) data from Landsat was also used and national events (polygons) were used to identify areas and types of disturbance.
        To read more about LF reference resources go to https://www.landfire.gov/reference.php. Information about LF 2022 product testing is available by request or via the website at https://www.landfire.gov.
      Process_Date: 20230501

Spatial_Data_Organization_Information:
  Direct_Spatial_Reference_Method: Raster
  Raster_Object_Information:
    Raster_Object_Type: Grid Cell
    Row_Count: 20729
    Column_Count: 24853

Spatial_Reference_Information:
  Horizontal_Coordinate_System_Definition:
    Planar:
      Map_Projection:
        Map_Projection_Name: Albers Conical Equal Area
        Albers_Conical_Equal_Area:
          Standard_Parallel: 29.5
          Standard_Parallel: 45.5
          Longitude_of_Central_Meridian: -96.0
          Latitude_of_Projection_Origin: 23.0
          False_Easting: 0
          False_Northing: 0
      Planar_Coordinate_Information:
        Planar_Coordinate_Encoding_Method: row and column
        Coordinate_Representation:
          Abscissa_Resolution: 30
          Ordinate_Resolution: 30
        Planar_Distance_Units: meters
    Geodetic_Model:
      Horizontal_Datum_Name: North American Datum of 1983 (NAD 83)
      Ellipsoid_Name: Geodetic Reference System 1980
      Semi-major_Axis: 6378137.000000
      Denominator_of_Flattening_Ratio: 298.257222
  Vertical_Coordinate_System_Definition:

Entity_and_Attribute_Information:
  Detailed_Description:
    Entity_Type:
      Entity_Type_Label: CBD
      Entity_Type_Definition: LF 2022 CBD attributes spreadsheet.
      Entity_Type_Definition_Source: LF 2022
    Attribute:
      Attribute_Label: VALUE
      Attribute_Definition:
        Forest Canopy Bulk Density (CBD) is the mass of available canopy fuel per unit canopy volume that would burn in a crown fire and values range from 0 to 45.
      Attribute_Definition_Source: LF 2020
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: -9999
          Enumerated_Domain_Value_Definition: No Data
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Range_Domain:
          Range_Domain_Minimum: 0
          Range_Domain_Maximum: 45
    Attribute:
      Attribute_Label: KGM3_X_100
      Attribute_Definition: CBD is kilograms per meter cubed multiplied by 100.
      Attribute_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: NoData
          Enumerated_Domain_Value_Definition: No Data
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: Non-Forested
          Enumerated_Domain_Value_Definition: Non-forested
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 01 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 01 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 02 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 02 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 03 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 03 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 04 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 04 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 05 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 05 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 06 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 06 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 07 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 07 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 08 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 08 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 09 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 09 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 10 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 10 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 11 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 11 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 12 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 12 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 13 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 13 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 14 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 14 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 15 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 15 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 16 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 16 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 17 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 17 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 18 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 18 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 19 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 19 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 20 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 20 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 21 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 21 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 22 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 22 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 23 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 23 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 24 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 24 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 25 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 25 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 26 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 26 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 27 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 27 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 28 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 28 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 29 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 29 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 30 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 30 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 31 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 31 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 32 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 32 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 33 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 33 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 34 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 34 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 35 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 35 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 36 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 36 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 37 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 37 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 38 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 38 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 39 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 39 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 40 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 40 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 41 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 41 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 42 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 42 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 43 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 43 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD = 44 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD = 44 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Enumerated_Domain:
          Enumerated_Domain_Value: CBD greater than or equal to 45 kg/m^3 X 100
          Enumerated_Domain_Value_Definition: CBD greater than or equal to 45 kg/m^3 X 100
          Enumerated_Domain_Value_Definition_Source: LF 2022
    Attribute:
      Attribute_Label: KGM3
      Attribute_Definition: Kilograms per meter cubed.
      Attribute_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Unrepresentable_Domain: Kilograms per meter cubed.
    Attribute:
      Attribute_Label: R
      Attribute_Definition: Red color value/255
      Attribute_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Range_Domain:
          Range_Domain_Minimum: 0
          Range_Domain_Maximum: 255
    Attribute:
      Attribute_Label: G
      Attribute_Definition: Green color value/255
      Attribute_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Range_Domain:
          Range_Domain_Minimum: 0
          Range_Domain_Maximum: 255
    Attribute:
      Attribute_Label: B
      Attribute_Definition: Blue color value/255
      Attribute_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Range_Domain:
          Range_Domain_Minimum: 0
          Range_Domain_Maximum: 255
    Attribute:
      Attribute_Label: RED
      Attribute_Definition: Red color value.
      Attribute_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Range_Domain:
          Range_Domain_Minimum: 0.0
          Range_Domain_Maximum: 1.0
    Attribute:
      Attribute_Label: GREEN
      Attribute_Definition: Green color value.
      Attribute_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Range_Domain:
          Range_Domain_Minimum: 0.0
          Range_Domain_Maximum: 1.0
    Attribute:
      Attribute_Label: BLUE
      Attribute_Definition: Blue color value.
      Attribute_Definition_Source: LF 2022
      Attribute_Domain_Values:
        Range_Domain:
          Range_Domain_Minimum: 0.0
          Range_Domain_Maximum: 1.0
  Overview_Description:
    Entity_and_Attribute_Overview:
      LANDFIRE (LF) 2022 Forest Canopy Bulk Density (CBD) CONUS. An Attribute Table is included with each product download as a .csv and embedded in the metadata. The Attribute Data Dictionary (ADD) can be found at https://www.landfire.gov/.
    Entity_and_Attribute_Detail_Citation: https://www.landfire.gov/cbd.php

Distribution_Information:
  Distributor:
    Contact_Information:
      Contact_Organization_Primary:
        Contact_Organization: U.S. Geological Survey
        Contact_Person: GS ScienceBase
      Contact_Address:
        Address_Type: mailing address
        Address: Denver Federal Center, Building 810, Mail Stop 302
        City: Denver
        State_or_Province: CO
        Postal_Code: 80225
        Country: United States
      Contact_Voice_Telephone: 1-888-275-8747
      Contact_Electronic_Mail_Address: sciencebase@usgs.gov
  Distribution_Liability:
    This product is reproduced from geospatial information prepared by the U.S. Department of the Interior (DOI) USGS EROS. By removing the contents of this package or taking receipt of these files via electronic file transfer methods, you understand that the data stored on this media can be updated at any time. Represented features may not be in an accurate geographic location. USGS EROS makes no expressed or implied warranty, including warranty of merchantability and fitness, with respect to the character, function, or capabilities of the data or their appropriateness for any user's purposes. USGS EROS reserves the right to correct, update, modify, or replace this geospatial information without notification.
    Unless otherwise stated, all data, metadata and related materials are considered to satisfy the quality standards relative to the purpose for which the data were collected. Although these data and associated metadata have been reviewed for accuracy and completeness and approved for release by the U.S. Geological Survey (USGS), no warranty expressed or implied is made regarding the display or utility of the data for other purposes, nor on all computer systems, nor shall the act of distribution constitute any such warranty.
  Standard_Order_Process:
    Digital_Form:
      Digital_Transfer_Information:
        Format_Name: ARCG
        Format_Version_Date: 20230501
        Format_Specification: LF 2022
      Digital_Transfer_Option:
        Online_Option:
          Computer_Contact_Information:
            Network_Address:
              Network_Resource_Name: https://doi.org/10.5066/P974JF8W
    Fees: none

Metadata_Reference_Information:
  Metadata_Date: 20230501
  Metadata_Contact:
    Contact_Information:
      Contact_Organization_Primary:
        Contact_Organization:
          LANDFIRE, Earth Resources Observation and Science Center (EROS), U.S. Geological Survey
      Contact_Position: Customer Service Representative
      Contact_Address:
        Address_Type: physical
        Address: 47914 252nd Street
        City: Sioux Falls
        State_or_Province: SD
        Postal_Code: 57198
        Country: U.S.
      Contact_Voice_Telephone: 605-594-6151
      Contact_Electronic_Mail_Address: helpdesk@landfire.gov
  Metadata_Standard_Name: FGDC Content Standard for Digital Geospatial Metadata
  Metadata_Standard_Version: FGDC-STD-001-1998
  Metadata_Time_Convention: local time
  Metadata_Security_Information:
    Metadata_Security_Classification_System: None
    Metadata_Security_Classification: Unclassified
    Metadata_Security_Handling_Description: None